@@ -10,7 +10,6 @@ from typing import Any, ClassVar, Dict, Iterable, List, Optional, Union
 from everyaction.core import EAObject, EAProperty, EAValue
 from everyaction.exception import EAException
 
-
 __all__ = [
     'ActivistCode',
     'ActivistCodeData',
@@ -33,6 +32,8 @@ __all__ = [
     'BulkImportField',
     'BulkImportJob',
     'BulkImportJobData',
+    'Campaign',
+    'CampaignType',
     'Canvasser',
     'CanvassContext',
     'CanvassFileRequest',
@@ -50,6 +51,8 @@ __all__ = [
     'Constraints',
     'ContactHistory',
     'ContactType',
+    'Content',
+    'ContentType',
     'Contribution',
     'Currency',
     'CustomField',
@@ -251,6 +254,7 @@ EAProperty.share(
     contactMethodPreferenceCode=EAProperty('contact_preference_code', 'preference_code', 'contact_preference'),
     contactMode=EAProperty(),
     contactModeId=EAProperty(),
+    contactSource=EAProperty(),
     contactTypeId=EAProperty('contact_type'),
     contentId=EAProperty('content'),
     contributionCount=EAProperty('contributions'),
@@ -277,6 +281,7 @@ EAProperty.share(
     cycle=EAProperty(),
     databaseMode=EAProperty('mode'),
     databaseName=EAProperty(),
+    dateAcquired=EAProperty(),
     dateAdjusted=EAProperty('adjusted', 'date'),
     dateCanvassed=EAProperty('canvassed'),
     dateCardsSent=EAProperty('cards_sent'),
@@ -312,6 +317,7 @@ EAProperty.share(
     disclosureFieldValue=EAProperty('field_value', 'disclosure_value', 'value'),
     displayMode=EAProperty(),
     displayName=EAProperty('display'),
+    disposition=EAProperty(),
     doorCount=EAProperty('door'),
     dotNetTimeZoneId=EAProperty('dot_net_time_zone', 'time_zone'),
     downloadUrl=EAProperty('download'),
@@ -705,6 +711,10 @@ class BargainingUnit(
     """
 
 
+class CampaignType(EAObject, _id='id', _name='name', _prefix="campaignType"):
+    """Represents a `Campaign Type <https://docs.everyaction.com/reference/campaigns-common-models#campaign-type>`__."""
+
+
 class Canvasser(EAObject, _id='id', _prefix='canvasser'):
     """Represents a `Canvasser <https://docs.everyaction.com/reference/common-models-25>`__."""
 
@@ -814,6 +824,10 @@ class ContactHistory(EAObject, _shared={'contactTypeId', 'dateCanvassed', 'input
     """Represents a `Contact History object <https://docs.everyaction.com/reference/post-people-vanid-notes>`__."""
 
 
+class ContentType(EAObject, _id='id', _name='name', _prefix='contentType'):
+    """Represents a `Content Type <https://docs.everyaction.com/reference/campaigns-common-models#content-type>`__."""
+
+
 class Currency(EAObject, _shared={'amount', 'currencyType'}):
     """Represents the type and the amount of a currency. Found, for instance, in the response of
     `GET /people/{vanId}/membership <https://docs.everyaction.com/reference/people-vanid-membership>`__.
@@ -1504,6 +1518,18 @@ class Code(
     """Represents a `Code object <https://docs.everyaction.com/reference/codes-common-models#code>`__."""
 
 
+class Content(
+    EAObject,
+    _id='id',
+    _name='name',
+    _prefix='content',
+    _prefixed={'type'},
+    _shared={'description', 'displayName', 'disposition', 'shortName'},
+    type=EAProperty(factory=ContentType)
+):
+    """Represents a `Content object <https://docs.everyaction.com/reference/campaigns-common-models#contents>`__."""
+
+
 class CustomField(
     EAObject,
     _id='id',
@@ -1865,6 +1891,7 @@ EAProperty.share(
     addresses=EAProperty(singular_alias='address', factory=Address),
     bulkImportFields=EAProperty(singular_alias='bulk_import_field', factory=ChangedEntityBulkImportField),
     codes=EAProperty(singular_alias='code', factory=Code),
+    contents=EAProperty(singular_alias='content', factory=Content),
     customFields=EAProperty(singular_alias='custom_field', factory=CustomField),
     districts=EAProperty(singular_alias='district', factory=DistrictField),
     districtFields=EAProperty(singular_alias='district_field', factory=DistrictField),
@@ -1921,6 +1948,18 @@ class BulkImportJobData(
     """
 
 
+class Campaign(
+    EAObject,
+    _id='id',
+    _name='name',
+    _prefix='campaign',
+    _prefixed={'displayName', 'type'},
+    _shared={'contents', 'displayName', 'status'},
+    type=EAProperty(factory=CampaignType)
+):
+    """Represents a `Campaign <https://docs.everyaction.com/reference/campaigns-common-models#campaign>`__."""
+
+
 class CanvassContext(
     EAObject,
     _shared={
@@ -2111,9 +2150,12 @@ class Person(
         'contactMethodPreferenceCode',
         'contactMode',
         'contactModeId',
+        'contactSource',
         'customFieldValues',
         'customProperties',
         'cycle',
+        'dateAcquired',
+        'dateCreated',
         'dateOfBirth',
         'disclosureFieldValues',
         'districts',
